/******************************************************************************

   FILE				: sci.c
   
   AUTHOR			: Axiom Manufacturing    					     
						  Spencer Ruggles
						  
	PURPOSE			: Manufacturing Test for EVB51JM128 board, x427
 
 ******************************************************************************
 
  Purpose:
  
  Mfg Functional Test routine for EVB51JM128 board, x427.  

******************************************************************************/

#include "MCF51JM128.h"			// include peripheral declarations 
#include "sci.h"					// sci header file

byte axstr[] = "AXIOM MANUFACTURING";	// output string
byte str1[] = "EVB51JM128, AXM-0427";	// output string
byte str2[] = "COM2 output";				// output string
byte pstr[] = "POT = 0x";					// output string for POT reading

/*******************************************************************************
display

	outputs formatted display to COM1 for test purposes 
********************************************************************************/
void display(){
	outstr(axstr);
	outstr(str1);
}
	
/*******************************************************************************
ensci(port)

	configures COM port selected by (port) for 19200,8,N,1 operation
	SCI baud rate register (SCIxBD) is written with value determined by 
	     SCIxBD = busclk/(16*baud) => SCIxBD = 0x0D -> 19.2 kHz
	     
	MCG trim value must be written to effectively use COM port 
********************************************************************************/
void ensci(byte port){
	if(port == 1) {   					// COM1 selected
		SCI1BD = baud19;						// 19.2 kHz
		SCI1C1 &= ~SCI1C1_M_MASK & ~SCI1C1_PE_MASK;	// 8,N,1
		SCI1C2 |= SCI1C2_TE_MASK | SCI1C2_RE_MASK;	// SCI Tx/Rx enabled
	} else {									// COM2 selected
		SCI2BD = baud19;						// 19,200 Hz
		SCI2C1 &= ~SCI2C1_M_MASK & ~SCI2C1_PE_MASK;	// 8,N,1
		SCI2C2 |= SCI2C2_TE_MASK | SCI2C2_RE_MASK;	// SCI Tx/Rx enabled
	}
}

/*******************************************************************************
crlf

	waits for Tx Data Register Empty flag then sends a carriage return (CR) and 
	line feed (LF) out selected COM port.  Tx Complete flag is used to provide 
	sufficient delay to get char through COM port
********************************************************************************/
void crlf(byte port){
	if (port == 1) {	 					// COM1 selected
		if(SCI1S1_TDRE) 
			SCI1D = LF;						// send line feed
		while (!SCI1S1_TC);				// wait until byte is sent
		if(SCI1S1_TDRE) 
			SCI1D = CR;						// send carrige return
		while (!SCI1S1_TC);				// wait until byte is sent
	} else {
		if(SCI2S1_TDRE) 
			SCI2D = LF;							// send line feed
		while (!SCI2S1_TC);					// wait until byte is sent
		if(SCI2S1_TDRE) 
			SCI2D = CR;							// send carrige return
		while (!SCI2S1_TC);					// wait until byte is sent
	}
}

/*******************************************************************************
outstr

	takes pointer to start of string of ASCII data and sends data to selected COM
	port
	
	INPUT:  selected COM port, unsigned char pointer
	OUTPUT: none
********************************************************************************/
void outstr(byte *cptr) {
	byte n;									// temp variable
	
	for(n=0;n<sizeof *cptr;n++){
		if(SCI1S1_TDRE) {					// wait until TX ready 
		 	SCI1D = cptr[n];				// send data
		}
		while(!SCI1S1_TC);				// wait until send is complete
	}
	crlf(1);									// send CR/LF on COM1
}

// output STR1 text string
void sci1out() {
	unsigned char n;						// temp variable
	for(n=0; n<sizeof str1; n++) {
		if(SCI1S1_TDRE) {					// wait until TX ready 
		 	SCI1D = str1[n];				// send data
		}
		while(!SCI1S1_TC);				// wait until send is complete
	}
	crlf(1);									// send CR/LF on COM1
}

// output STR2 text string
void sci2out() {
	unsigned char n;						// temp variable
	for(n=0; n<sizeof str2; n++) {
		if(SCI2S1_TDRE) {					// wait until TX ready 
		 	SCI2D = str2[n];				// send data
		}
		while(!SCI2S1_TC);				// wait for send to complete
	}
	crlf(2);									// send CR/LF on COM2
}

/*******************************************************************************
putch

	waits for Tx Data Register Empty flag then sends a single ASCII char out 
	COM1 port.  Tx Complete flag is used to provide sufficient delay to get 
	char through COM1 port
********************************************************************************/
void putch(byte a) {
	if(SCI1S1_TDRE) {						// wait until TX ready 
		SCI1D = a;							// send data
	}
	while(!SCI1S1_TC);					// wait for send to complete
}

/*******************************************************************************
outhex

	input: 8-bit hex value 
	outpt: ASCII representation of input
********************************************************************************/
void outhex(byte hval){
	// convert input HEX value to output ASCII text

	unsigned char unib,lnib;			// temp variable for upper and lower nibbles
	
	unib = (hval >> 4);					// high nibble
	lnib = hval & 0x0F;					// low nibble

	putch(hex2char(unib));				// send char out
	putch(hex2char(lnib));				// send char out
}  

/*******************************************************************************
hex2char

	input: 4-bit hex value in low nibble of input
	outpt: ASCII representation of input
********************************************************************************/
unsigned char hex2char(unsigned char cval) {
	if(cval < 0x0A) {
		cval += 0x30;						// convert high nibble numeric to ASCII text 
	} else {
		cval += 0x37;						// convert high nibble alpha to ASCII text
	}
	return cval;							// return ASCII char
}


